@@ -532,11 +532,6 @@ async def on_message(message):
         await bot.process_commands(message)
         if bot.user.mentioned_in(message):
                 await message.channel.send("My prefix is m!")
-def login(token):
-    try:
-        keep_alive()
-        bot.run(token)
-        print("Login Successfully")
-    except:
-        print("Login error")
-bot.run(os.getenv("token"))
+def login(token : str):
+    keep_alive()
+    bot.run(token)
